{ config, lib, pkgs, ... }:

let
  unstable = import <nixos-unstable> { config.allowUnfree = true; };
  cloudstation = pkgs.callPackage (import ../packages/cloudstation.nix) {};
  nagstamon = pkgs.libsForQt5.callPackage (import ../packages/nagstamon.nix) {};
in {

  security.pki.certificateFiles = [
    ../dotfiles/certs/NetzmarktCA.crt
    ../dotfiles/certs/vcenter.netzmarkt.lan.crt
  ];

  networking.extraHosts = ''
    35.234.109.94 fsi.thomann.de
    10.100.7.11 mon.netzmarkt.de

    172.23.0.2 api.kube.local
    172.23.0.2 hubble.kube.local
    172.23.0.2 bonedo.kube.local
    172.23.0.2 linkerd.kube.local
    172.23.0.2 argo.kube.local

  '';

  environment.systemPackages = with pkgs; [
    (import ../packages/oc311.nix)
    (import ../packages/oc46.nix)
    (import ../packages/openshift-install-4.5.nix)
    # (import ../packages/vaultsink.nix) needs opensource verson
    cloudstation
    nagstamon

    drone-cli
    go-jira
    govc
    ttyd
    unstable.discord
    unstable.google-cloud-sdk
    unstable.slack
    unstable.velero

    unstable.obs-studio
    unstable.obs-studio-plugins.wlrobs
  ];
}
